#
# spec file for package MistServer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           MistServer
Version:        3.6.1
Release:        1.1
Summary:        Next-generation streaming media toolkit for internet streaming.
License:        Unlicense
URL:            https://github.com/DDVTECH/mistserver
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.service
Source2:        mistserver.sysuser
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  group(video)
BuildRequires:  pkgconfig(librist)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(mbedtls) < 3
BuildRequires:  pkgconfig(srt)
BuildRequires:  pkgconfig(usrsctp)
Requires:       group(video)
Recommends:     ffmpeg
%sysusers_requires
%{?systemd_ordering}

%description
%{name} is an open source, public domain, full-featured,
next-generation streaming media toolkit for OTT (internet streaming),
designed to be ideal for developers and system integrators.

%package devel
Summary:        Development files for %{name}
BuildArch:      noarch

%description devel
Development files for %{name}.

%prep
%autosetup -n mistserver-%{version}

%build
%meson \
  -DDEBUG=3 \
  -DLOCAL_GENERATORS=false \
  -DNOGA=true \
  -DNOUPDATE=true
%meson_build

%sysusers_generate_pre %{SOURCE2} %{name} %{name}.conf

%install
%meson_install

# service
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_sysusersdir}/mistserver.conf

%pre -f %{name}.pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license UNLICENSE
%doc README.md
%ghost %config(noreplace) %attr(0644, root, mistserver) %{_sysconfdir}/%{name}.json
%{_bindir}/MistAnalyserDTSC
%{_bindir}/MistAnalyserEBML
%{_bindir}/MistAnalyserFLAC
%{_bindir}/MistAnalyserFLV
%{_bindir}/MistAnalyserH264
%{_bindir}/MistAnalyserHLS
%{_bindir}/MistAnalyserMP4
%{_bindir}/MistAnalyserOGG
%{_bindir}/MistAnalyserRIFF
%{_bindir}/MistAnalyserRTMP
%{_bindir}/MistAnalyserRTSP
%{_bindir}/MistAnalyserTS
%{_bindir}/MistController
%{_bindir}/MistInAAC
%{_bindir}/MistInBalancer
%{_bindir}/MistInBuffer
%{_bindir}/MistInDTSC
%{_bindir}/MistInEBML
%{_bindir}/MistInFLAC
%{_bindir}/MistInFLV
%{_bindir}/MistInFolder
%{_bindir}/MistInH264
%{_bindir}/MistInHLS
%{_bindir}/MistInISMV
%{_bindir}/MistInMP3
%{_bindir}/MistInMP4
%{_bindir}/MistInOGG
%{_bindir}/MistInPlaylist
%{_bindir}/MistInRTSP
%{_bindir}/MistInSDP
%{_bindir}/MistInSubRip
%{_bindir}/MistInTS
%{_bindir}/MistInTSRIST
%{_bindir}/MistInTSSRT
%{_bindir}/MistInV4L2
%{_bindir}/MistOutAAC
%{_bindir}/MistOutCMAF
%{_bindir}/MistOutDTSC
%{_bindir}/MistOutEBML
%{_bindir}/MistOutFLAC
%{_bindir}/MistOutFLV
%{_bindir}/MistOutH264
%{_bindir}/MistOutHDS
%{_bindir}/MistOutHLS
%{_bindir}/MistOutHTTP
%{_bindir}/MistOutHTTPMinimalServer
%{_bindir}/MistOutHTTPS
%{_bindir}/MistOutHTTPTS
%{_bindir}/MistOutJPG
%{_bindir}/MistOutJSON
%{_bindir}/MistOutJSONLine
%{_bindir}/MistOutMP3
%{_bindir}/MistOutMP4
%{_bindir}/MistOutOGG
%{_bindir}/MistOutRTMP
%{_bindir}/MistOutRTSP
%{_bindir}/MistOutSDP
%{_bindir}/MistOutSubRip
%{_bindir}/MistOutTS
%{_bindir}/MistOutTSRIST
%{_bindir}/MistOutTSSRT
%{_bindir}/MistOutWAV
%{_bindir}/MistOutWebRTC
%{_bindir}/MistProcFFMPEG
%{_bindir}/MistProcLivepeer
%{_bindir}/MistProcMKVExec
%{_bindir}/MistSession
%{_bindir}/MistTranslateH264
%{_bindir}/MistUtilAMF
%{_bindir}/MistUtilCertbot
%{_bindir}/MistUtilLog
%{_bindir}/MistUtilMETA
%{_bindir}/MistUtilNuke
%{_bindir}/MistUtilRAX
%{_libdir}/libmist.so
%{_libdir}/libmist_srt.so
%{_sysusersdir}/mistserver.conf
%{_unitdir}/%{name}.service

%files devel
%{_includedir}/mist

%changelog
* Sun May 11 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Make it final
* Sat May 10 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Debug dependancy unresolvability
* Fri May  9 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Fix user config install X2
* Fri May  9 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Fix user config install
* Wed May  7 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Finilize project for the first Factory release.
* Mon May  5 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Remove unneeded and dangerous /dev/shm cleanup from the systemd service file.
* Mon May  5 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Remove unneeded build dependencies.
* Sun May  4 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Temporarily switch to home selfbuilt libraries to produce complete working builds.
* Fri May  2 2025 Yoshio Sato <vasua.ukraine@gmail.com>
- Initial packaging, thanks to Georg, Richard, Gertjan and my imaginary friends.
